==> amarok-2.2.2.tar.bz2: amarok-2.2.2/tests/TestDirectoryLoader.h <==
/***************************************************************************
 *   Copyright (c) 2009 Sven Krohlas <sven@getamarok.com>                  *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.         *
 ***************************************************************************/

#ifndef TESTDIRECTORYLOADER_H
#define TESTDIRECTORYLOADER_H

#include "DirectoryLoader.h"

#include <QtCore/QStringList>
#include <QtCore/QMutex>

class TestDirectoryLoader : public QObject
{
Q_OBJECT

public:
    TestDirectoryLoader( QStringList testArgumentList, bool stdout );

public slots:
    void loadersFinished();

private slots:
    void testInitAndInsertAtRow();

private:
    int m_finishedLoaders;
    QMutex m_mutex;
    QStringList m_testArgumentList;
};

#endif // TESTDIRECTORYLOADER_H

==> amarok-2.4.0.tar.bz2: amarok-2.4.0/tests/TestDirectoryLoader.h <==
/***************************************************************************
 *   Copyright (c) 2009 Sven Krohlas <sven@getamarok.com>                  *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.         *
 ***************************************************************************/

#ifndef TESTDIRECTORYLOADER_H
#define TESTDIRECTORYLOADER_H

#include "DirectoryLoader.h"
#include "TestBase.h"

#include <QtCore/QStringList>
#include <QtCore/QMutex>

class TestDirectoryLoader : public TestBase
{
Q_OBJECT

public:
    TestDirectoryLoader( const QStringList args, const QString &logPath );

public slots:
    void loadersFinished();

private slots:
    void testInitAndInsertAtRow();

private:
    int m_finishedLoaders;
    QMutex m_mutex;
    QStringList m_testArgumentList;
};

#endif // TESTDIRECTORYLOADER_H
